# Dependencies for Windows


## For Android test
- Install `ADB` (Android Debug Bridge)

	If already installed, just skip the part. recommend version `1.0.36`

	* Download address 1: <https://github.com/codeskyblue/AutomatorX/releases/download/1.0.12/adb-1.0.36.zip>
	* Download address 2: <https://developer.android.com/studio/index.html> just download android-sdk
	* Download address 3: <http://adbshell.com> (this site update not too fast)

	After download, add `adb.exe` to PATH

## For iOS test
- iTunes(或iTools)
- [iMobileDevice](http://quamotion.mobi/iMobileDevice/Download)

两款软件下载安装到电脑上(如果安装了iTools可以不用安装iTunes)
另外iMobileDevice安装完之后，需要将其添加到PATH变量中.

安装完之后，iPhone手机需要开启开发者模式才能正常的截图,用iTools可以很方便的完成这个工作
